(this.webpackJsonpst_table_words_icon=this.webpackJsonpst_table_words_icon||[]).push([[0],{13:function(e,t,c){"use strict";c.r(t);var r=c(1),s=c.n(r),n=c(4),a=c.n(n),o=c(2),i=c(0),l=Object(o.b)((function(e){var t=e.args.words;return Object(r.useEffect)((function(){var e=function(e){if("span"===e.target.tagName.toLowerCase()&&e.target.classList.contains("material-icons")){var t=e.target.getAttribute("data-word");t&&o.a.setComponentValue(t)}};return o.a.setFrameHeight(document.documentElement.scrollHeight),document.addEventListener("click",e),function(){document.removeEventListener("click",e)}}),[]),Object(i.jsx)("div",{className:"card",style:{height:"600px",overflowY:"scroll"},children:Object(i.jsxs)("table",{className:"table table-borderless",children:[Object(i.jsx)("thead",{children:Object(i.jsx)("tr",{children:Object(i.jsx)("th",{scope:"col",children:"Nom"})})}),Object(i.jsx)("tbody",{children:t.map((function(e,t){return Object(i.jsx)("tr",{children:Object(i.jsxs)("td",{children:[e," ",Object(i.jsx)("span",{"data-word":e,className:"material-icons",style:{color:"#037afb",fontSize:"18px",verticalAlign:"text-bottom",cursor:"pointer"},children:"visibility"})]})},t)}))})]})})}));a.a.render(Object(i.jsx)(s.a.StrictMode,{children:Object(i.jsx)(l,{})}),document.getElementById("root"))}},[[13,1,2]]]);
//# sourceMappingURL=main.5f334551.chunk.js.map