import setuptools
from os.path import dirname
from os.path import join


def readme() -> str:
    """Utility function to read the README file.
    Used for the long_description.  It's nice, because now 1) we have a top
    level README file and 2) it's easier to type in the README file than to put
    a raw string in below.
    :return: content of README.md
    """
    return open(join(dirname(__file__), "README.md")).read()


setuptools.setup(
    name="st_table_words_icon",
    version="0.0.9",
    author="Andell",
    author_email="drogadvc@gmail.com",
    description="Streamlit table sidebar with icon for click",
    packages=setuptools.find_packages(),
    long_description=readme(),
    long_description_content_type="text/markdown",
    url="",
    include_package_data=True,
    classifiers=[],
    python_requires=">=3.7",
    install_requires=[
        # By definition, a Custom Component depends on Streamlit.
        # If your component has other Python dependencies, list
        # them here.
        "streamlit >= 0.63",
    ],
)
